==> iscflutterplugin-1.0.1.tar.gz: lib/isc_http.dart <==
import 'dart:convert';

import 'package:crypto/crypto.dart';
import 'package:dio/dio.dart';
import 'package:flutter/material.dart';

const String ARTEMIS_PATH = "/artemis";

///预览url地址
const String previewURLs = "$ARTEMIS_PATH/api/video/v1/cameras/previewURLs";

///云台控制
const String controlling = "$ARTEMIS_PATH/api/video/v1/ptzs/controlling";

///回放url地址
const String playbackURLs = "$ARTEMIS_PATH/api/video/v1/cameras/playbackURLs";

class ArtemisConfig {
  static String host;
  static String appKey;
  static String appSecret;

  ///根据路径生成认证header
  ///海康isc平台采用AK/SK认证,需要生成生成必要的秘钥放到header中
  /// 'url' 接口请求地址 比如[previewURLs],[controlling]..等
  static Map<String, dynamic> createHeaders(String url) {
    assert(ArtemisConfig.host != null);
    assert(ArtemisConfig.appKey != null);
    assert(ArtemisConfig.appSecret != null);

    var httpHeaders = "POST\n*/*\napplication/json\n";
    var customHeaders = "x-ca-key:${ArtemisConfig.appKey}\n";
    var msg = httpHeaders + customHeaders + url;
    var secretBytes = utf8.encode(ArtemisConfig.appSecret);
    var messageBytes = utf8.encode(msg);
    var digest = Hmac(sha256, secretBytes).convert(messageBytes);
    var signature = base64Encode(digest.bytes);

    Map<String, dynamic> headers = Map();
    headers["Accept"] = "*/*";
    headers["Content-Type"] = "application/json";
    headers["X-Ca-Key"] = ArtemisConfig.appKey;
    headers["X-Ca-Signature"] = signature;
    headers["X-Ca-Signature-Headers"] = "x-ca-key";
    return headers;
  }
}

///isc平台网络请求辅助类
class IscApi {
  ///获取预览地址
  /// 'cameraIndexCode' 监控点唯一标识
  /// 'streamType' 码流类型,0主码流,1子码流
  static Future<String> getPreviewURL({
    @required String cameraIndexCode,
    int streamType = 1,
  }) async {
    var headers = ArtemisConfig.createHeaders(previewURLs);
    String url = 'http://${ArtemisConfig.host}$previewURLs';

    Map body = Map();
    body['cameraIndexCode'] = cameraIndexCode;
    body['streamType'] = streamType;

    Dio dio = Dio();
    dio.options.headers.addAll(headers);
    Response response = await dio.post(url, data: body);
    return response.data['data']['url'];
  }

  /// 云台控制
  /// 'cameraIndexCode' 监控点唯一标识
  /// 'action' 行为:0开始,1停止
  ///
  /// 'command' 命令:不区分大小写
  /// 说明：
  /// LEFT 左转
  /// RIGHT右转
  /// UP 上转
  /// DOWN 下转
  /// ZOOM_IN 焦距变大
  /// ZOOM_OUT 焦距变小
  /// LEFT_UP 左上
  /// LEFT_DOWN 左下
  /// RIGHT_UP 右上
  /// RIGHT_DOWN 右下
  /// FOCUS_NEAR 焦点前移
  /// FOCUS_FAR 焦点后移
  /// IRIS_ENLARGE 光圈扩大
  /// IRIS_REDUCE 光圈缩小；
  /// 以下命令presetIndex不可为空：
  /// GOTO_PRESET到预置点
  static Future<String> ptzControl(
      String cameraIndexCode, int action, String command) async {
    var headers = ArtemisConfig.createHeaders(controlling);
    String url = 'http://${ArtemisConfig.host}$controlling';

    Map body = Map();
    body['cameraIndexCode'] = cameraIndexCode;
    body['action'] = action;
    body['command'] = command;

    Dio dio = Dio();
    dio.options.headers.addAll(headers);
    Response response = await dio.post(url, data: body);
    return response.data;
  }
}

==> iscflutterplugin-1.0.2.tar.gz: lib/isc_http.dart <==
import 'dart:convert';

import 'package:crypto/crypto.dart';
import 'package:dio/dio.dart';
import 'package:flutter/material.dart';

const String ARTEMIS_PATH = "/artemis";

///预览url地址
const String previewURLs = "$ARTEMIS_PATH/api/video/v1/cameras/previewURLs";

///云台控制
const String controlling = "$ARTEMIS_PATH/api/video/v1/ptzs/controlling";

///回放url地址
const String playbackURLs = "$ARTEMIS_PATH/api/video/v1/cameras/playbackURLs";

class ArtemisConfig {
  static String host;
  static String appKey;
  static String appSecret;

  ///根据路径生成认证header
  ///海康isc平台采用AK/SK认证,需要生成生成必要的秘钥放到header中
  /// 'url' 接口请求地址 比如[previewURLs],[controlling]..等
  static Map<String, dynamic> createHeaders(String url) {
    assert(ArtemisConfig.host != null);
    assert(ArtemisConfig.appKey != null);
    assert(ArtemisConfig.appSecret != null);

    var httpHeaders = "POST\n*/*\napplication/json\n";
    var customHeaders = "x-ca-key:${ArtemisConfig.appKey}\n";
    var msg = httpHeaders + customHeaders + url;
    var secretBytes = utf8.encode(ArtemisConfig.appSecret);
    var messageBytes = utf8.encode(msg);
    var digest = Hmac(sha256, secretBytes).convert(messageBytes);
    var signature = base64Encode(digest.bytes);

    Map<String, dynamic> headers = Map();
    headers["Accept"] = "*/*";
    headers["Content-Type"] = "application/json";
    headers["X-Ca-Key"] = ArtemisConfig.appKey;
    headers["X-Ca-Signature"] = signature;
    headers["X-Ca-Signature-Headers"] = "x-ca-key";
    return headers;
  }
}

///isc平台网络请求辅助类
class IscApi {
  ///获取预览地址
  /// 'cameraIndexCode' 监控点唯一标识
  /// 'streamType' 码流类型,0主码流,1子码流
  static Future<dynamic> getPreviewURL({
    @required String cameraIndexCode,
    int streamType = 1,
  }) async {
    var headers = ArtemisConfig.createHeaders(previewURLs);
    String url = 'http://${ArtemisConfig.host}$previewURLs';

    Map body = Map();
    body['cameraIndexCode'] = cameraIndexCode;
    body['streamType'] = streamType;

    Dio dio = Dio();
    dio.options.headers.addAll(headers);
    Response response = await dio.post(url, data: body);
    return response.data;
  }

  /// 云台控制
  /// 'cameraIndexCode' 监控点唯一标识
  /// 'action' 行为:0开始,1停止
  ///
  /// 'command' 命令:不区分大小写
  /// 说明：
  /// LEFT 左转
  /// RIGHT右转
  /// UP 上转
  /// DOWN 下转
  /// ZOOM_IN 焦距变大
  /// ZOOM_OUT 焦距变小
  /// LEFT_UP 左上
  /// LEFT_DOWN 左下
  /// RIGHT_UP 右上
  /// RIGHT_DOWN 右下
  /// FOCUS_NEAR 焦点前移
  /// FOCUS_FAR 焦点后移
  /// IRIS_ENLARGE 光圈扩大
  /// IRIS_REDUCE 光圈缩小；
  /// 以下命令presetIndex不可为空：
  /// GOTO_PRESET到预置点
  static Future<dynamic> ptzControl(
      String cameraIndexCode, int action, String command) async {
    var headers = ArtemisConfig.createHeaders(controlling);
    String url = 'http://${ArtemisConfig.host}$controlling';

    Map body = Map();
    body['cameraIndexCode'] = cameraIndexCode;
    body['action'] = action;
    body['command'] = command;

    Dio dio = Dio();
    dio.options.headers.addAll(headers);
    Response response = await dio.post(url, data: body);
    return response.data;
  }
}
